@@ -1,7 +1,6 @@
 
 import sys
 import os
-import re
 import pickle
 import multiprocessing
 import ConfigParser as configparser
@@ -28,9 +27,11 @@ class PyTrailerWidget(QMainWindow):
 
     def __init__(self, *args):
         QMainWindow.__init__(self, *args)
-        READ_AHEAD_PROC = 4
         self.config = configparser.SafeConfigParser({'downloadDir':'/tmp',
-                                       'filters':pickle.dumps([])})
+                                       'filters':pickle.dumps([]),
+                                       'readAhead':'4',
+                                       'parallelDownload':'2'})
+        readAhead = int(self.config.get("DEFAULT","readAhead"))
         self.config.read(self.configPath)
         self.movieDict = {}
         self.readAheadTaskQueue = multiprocessing.Queue()
@@ -39,7 +40,7 @@ class PyTrailerWidget(QMainWindow):
         self.trailerDownloadDict = multiprocessing.Manager().dict()
 
         self.readAheadProcess = []
-        for i in range(READ_AHEAD_PROC):
+        for i in range(readAhead):
             p = multiprocessing.Process(target=movieReadAhead,
                         args=(self.readAheadTaskQueue,
                               self.readAheadDoneQueue))
@@ -48,7 +49,7 @@ class PyTrailerWidget(QMainWindow):
 
         self.downloader = TrailerDownloader(self.trailerDownloadQueue,
                                self.trailerDownloadDict,
-                               2)
+                               int(self.config.get("DEFAULT","parallelDownload")))
         self.downloader.start()
         self.init_widget()
         self.init_menus()
@@ -129,6 +130,7 @@ class PyTrailerWidget(QMainWindow):
         d = PyTrailerSettings(self.config)
         if d.exec_() == QDialog.Accepted:
             self.saveConfig()
+
     def about(self):
         w = PyTrailerAbout(self)
         w.exec_()
@@ -165,15 +167,10 @@ class PyTrailerWidget(QMainWindow):
         self.movieList = amt.getMoviesFromJSON(url)
         for i in range(len(self.movieList)):
             self.readAheadTaskQueue.put((i, self.movieList[i], self.loadID))
-        filt = TrailerFilter()
         filters = pickle.loads(self.config.get("DEFAULT",'filters'))
-        for trailerFilter in filters:
-            filt.addCondition(trailerFilter)
-        if len(filters) == 0:
-            filt.addCondition(".*")
 
         for movie in self.movieList:
-            w=MovieItemWidget(movie, filt, self.scrollArea)
+            w=MovieItemWidget(movie, filters, self.scrollArea)
             w.setVisible(False)
             w.downloadClicked.connect(self.downloadTrailer)
             w.viewClicked.connect(self.viewTrailer)
@@ -249,26 +246,6 @@ class PyTrailerWidget(QMainWindow):
         subprocess.Popen(command)
 
 
-class TrailerFilter(object):
-    """Class to create filter so that we can show only
-    some of the trailers (only HD/only 480p etc)
-    """
-    def __init__(self):
-        self.conditions=[]
-
-    def addCondition(self, regex):
-        """Adds another condition that makes movie visible
-        """
-        self.conditions.append(re.compile(regex))
-
-    def visible(self, trailerURL):
-        """Class returns true if the trailer should be visible
-        """
-        for cond in self.conditions:
-            if re.match(cond, trailerURL):
-                return True
-        return False
-
 def movieReadAhead(taskQueue, doneQueue):
     """Function to be run in separate process,
     caching additional movie information
